<?php

namespace Drupal\appnexus\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\appnexus\Tag;

/**
 * AppNexus Advertisement block
 *
 * @Block(
 *  id = "appnexus",
 *  admin_label = @Translation("AppNexus Block"),
 * )
 */
class AppNexusBlock extends BlockBase implements BlockPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $config = $this->getConfiguration();

    $form = parent::blockForm($form, $form_state);

    $form['tagId'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Tag ID'),
      '#default_value' => !empty($config['tagId']) ? $config['tagId'] : '',
      '#required'      => TRUE,
    ];

    $form['sizes'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Size(s)'),
      '#description'   => $this->t('Example: 300x600,300x250.'),
      '#required'      => TRUE,
      '#maxlength'     => 64,
      '#default_value' => !empty($config['sizes']) ? $config['sizes'] : '',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->setConfigurationValue('tagId', $form_state->getValue('tagId'));
    $this->setConfigurationValue('sizes', $form_state->getValue('sizes'));
    $this->setConfigurationValue('targetId', uniqid('adblock-'));
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();
    $tag = (new Tag())
      ->setTagId($config['tagId'])
      ->setSizes($config['sizes'])
      ->setTargetId($config['targetId']);
    $build = [
      '#type'   => 'markup',
      '#markup' => '<div id="' . $tag->getTargetId() . '"></div>',
    ];
    if ($opts = $tag->build()) {
      $build['#attached']['drupalSettings']['appnexus']['tags'][$tag->getTargetId()] = $opts;
    }
    return $build;
  }

}
